## 1.0.1 (2021-12-30)

### Fix

* Replace auto merge with echo (#5) [Anthony Mahanna]

* README colab link. [aMahanna]


## 1.0.0 (2021-12-30)

### New

* Mirror networkx-adapter changes (#3) [Anthony Mahanna]

* Notebook. [aMahanna]

* Workflow_dispatch. [aMahanna]

* __insert_adb_docs. [aMahanna]

* Readme & logos. [aMahanna]

### Changes

* Actions. [aMahanna]

### Fix

* Arangorestore. [aMahanna]

* Typo. [aMahanna]

* NotImplementedError() [aMahanna]

* Typo. [aMahanna]

* Tests. [aMahanna]

### Other

* Minor repo restructure & documentation update. [aMahanna]

* Update README.md. [aMahanna]

* Cleanup. [aMahanna]

* Update ArangoDB_DGL_Adapter.ipynb. [aMahanna]

* Update extract_version.py. [aMahanna]

* Update README.md. [Anthony Mahanna]

* Update README.md. [Anthony Mahanna]

* Update test_adbdgl_adapter.py. [aMahanna]

* Delete main.py. [Anthony Mahanna]

* Cleanup. [aMahanna]

* Update adbdgl_adapter.py. [aMahanna]

* Cleanup & doc strings. [aMahanna]

* Update setup.py. [aMahanna]

* Cleanup. [aMahanna]

* :night_with_stars: [aMahanna]

* Update conftest.py. [aMahanna]

* Update conftest.py. [aMahanna]

* Update conftest.py. [aMahanna]

* Update conftest.py. [aMahanna]

* Update conftest.py. [aMahanna]

* Update conftest.py. [aMahanna]

* Update conftest.py. [aMahanna]

* Update conftest.py. [aMahanna]

* More cleanup & batch insertion. [aMahanna]

* Cleanup. [aMahanna]

* :rocket: [aMahanna]

* Update adbdgl_adapter.py. [aMahanna]

* Update adbdgl_adapter.py. [aMahanna]

* Update adbdgl_adapter.py. [aMahanna]

* Update adbdgl_controller.py. [aMahanna]

* Checkpoint. [aMahanna]

* Remove py 3.10. [aMahanna]

* Initial commit. [aMahanna]


